Brown Paper Tickets - The fair-trade ticketing company.
Description: Brown Paper Tickets - The first and only fair trade ticketing company!
Keywords: ticket buy sell tickets events event registration

| View site in English, Español, or Français

Sign Me Up! | | | Log In |
Go | Forget your login?

The Solo Speak Sessions...
Armature @ The Old Ironworks Arts... BEND, OR
Sat Jan 09, 7:30 PM
Dressy Bessy
Atwood's Tavern Cambridge, MA
Wed Feb 10, 9:15 PM
T. J. Stiles in convers...
Kepler's Books Menlo Park, CA
Mon Jan 18, 7:30 PM
COMEDY |
Cellar Sessions
Old Oak Cellars Pasadena, CA
Sun Jan 10, 3:00 PM
In Chaos I Trust
The Red Sandcastle Theatre Toronto, ON
Fri Feb 12, 8:00 PM
Person In Charge Food S...
Center for Community Health Vancouver, WA
Wed Jun 15, 12:30 PM
Electric Eye with Mysti...
7th Street Thetare Hoquiam, WA
Fri Jan 08, 7:30 PM
Paint Night with Easy E...
Harbor Arts Center @ Harbor Theater Suisun City, CA
Sat Dec 19, 7:00 PM
Timberlina's Beard Melt...
The Marlborough Theatre Brighton United Kingdom
Thu Feb 11, 8:00 PM
MUSIC |
Fisk Jubilee Singers at...
duPont Chapel, Hollins University Roanoke, VA
Sun Feb 28, 3:00 PM
The Organizer on the Ro...
Kent Regional Library Kent, WA
Sun Jan 31, 2:00 PM
Joshu + Vela Sessions
Joshu + Vela San Francisco, CA
Wed Dec 16, 7:00 PM
PEPS Lecture - Choosing...
ROMP Bellevue, WA
Thu Jan 21, 6:30 PM
HOLIDAY CAMP Session I
Holiday Break Camp Truckee, CA
Mon Dec 21, 9:00 AM
The Solo Speak Sessions...
Armature @ The Old Ironworks Arts... BEND, OR
Sat Jan 09, 7:30 PM
Dressy Bessy
Atwood's Tavern Cambridge, MA
Wed Feb 10, 9:15 PM
T. J. Stiles in convers...
Kepler's Books Menlo Park, CA
Mon Jan 18, 7:30 PM
Basement Performances:...
The Drawing Center New York, NY
Sat Jan 30, 7:30 PM
DIFF DOPE BALL: I.L.A.M...
BACK BAR SoFA SAN JOSE, CA
Sat Dec 19, 9:00 PM
CONFIDENTIAL MUSICAL TH...
The Savoy Theatre Glace Bay, NS
Sat Feb 27, 7:00 PM
4x4x40 Beer Dinner with...
Devotay Iowa City, IA
Mon Jan 25, 6:00 PM
A Celtic Celebration
Dallas City Performance Hall Dallas, TX
Sun Mar 06, 2:30 PM
Austin Baroque Orchestr...
First Presbyterian Church Austin, TX
Sat Feb 20, 8:00 PM
Mandorla Music presents...
Third Life Studio Somerville, MA
Fri Jan 29, 8:00 PM
Buble Time Xmas Show
SWX Bristol Bristol United Kingdom
Wed Dec 16, 6:30 PM
Fisk Jubilee Singers at...
duPont Chapel, Hollins University Roanoke, VA
Sun Feb 28, 3:00 PM
The Organizer on the Ro...
Kent Regional Library Kent, WA
Sun Jan 31, 2:00 PM
Joshu + Vela Sessions
Joshu + Vela San Francisco, CA
Wed Dec 16, 7:00 PM
In Chaos I Trust
The Red Sandcastle Theatre Toronto, ON
Fri Feb 12, 8:00 PM
Person In Charge Food S...
Center for Community Health Vancouver, WA
Wed Jun 15, 12:30 PM
Electric Eye with Mysti...
7th Street Thetare Hoquiam, WA
Fri Jan 08, 7:30 PM
Paint Night with Easy E...
Harbor Arts Center @ Harbor Theater Suisun City, CA
Sat Dec 19, 7:00 PM
Timberlina's Beard Melt...
The Marlborough Theatre Brighton United Kingdom
Thu Feb 11, 8:00 PM
Red Light Variety Show...
Visual Arts Collective Garden City, ID
Thu Jan 14, 8:00 PM
DIFF DOPE BALL: I.L.A.M...
BACK BAR SoFA SAN JOSE, CA
Sat Dec 19, 9:00 PM
CONFIDENTIAL MUSICAL TH...
The Savoy Theatre Glace Bay, NS
Sat Feb 27, 7:00 PM
EDUCATION |
A Celtic Celebration
Dallas City Performance Hall Dallas, TX
Sun Mar 06, 2:30 PM
Fresh Ideas with Fresh...
Worcester Art Museum Worcester, MA
Sat Jan 30, 10:30 AM
Symbols, Saints & Grues...
Meet by the seating on the mezzan... London United Kingdom
Sat Jan 16, 11:00 AM
Christmas in East Liberty
East Liberty Presbyterian Church Pittsburgh, PA
Fri Dec 18, 7:30 PM
Bluegrass Event - One-M...
CATTLE TRACK ARTS COMPOUND AND TH... SCOTTSDALE, AZ
Thu Feb 04, 7:00 PM
PEPS Lecture - Choosing...
ROMP Bellevue, WA
Thu Jan 21, 6:30 PM
Austin Baroque Orchestr...
First Presbyterian Church Austin, TX
Sat Feb 20, 8:00 PM
Miss Spokane Awards Rec...
The Spokane Club Spokane, WA
Sun Jan 10, 6:00 PM
One Day Basketmaking Co...
St Margaret's House, Room 5.18 Edinburgh United Kingdom
Sat Mar 12, 10:00 AM
YouTube MeTube WeTube
Shoreline Community College Theater Shoreline, WA
Sat Feb 06, 7:00 PM
5K Salmon Run & Nature...
Ovenell's Double O Ranch Concrete, WA
Sat Jan 02, 9:00 AM
Austin Anarchy Roller D...
Austin Sports Arena Round Rock, TX
Sat Mar 19, 7:30 PM
Excognito Dance Festiva...
The Actor's Fund Arts Center Brooklyn, NY
Fri Jan 08, 7:30 PM
New Year's Eve
The Queens Kickshaw Astoria, NY
Thu Dec 31, 5:45 PM
Jukebox Madness: 2nd An...
Hermosa Ballroom at Robson Ranch Eloy, AZ
Fri Jan 22, 6:00 PM
VDAY 2016 - The Vagina...
The Church Within Indianapolis, IN
Fri Feb 12, 7:00 PM
DTLA December Queer Mal...
Santee Village Lofts Los Angeles, CA
Sun Dec 27, 1:00 PM
Perlesque
All that Glitters Burlesque Academy Portland, OR
Fri Mar 18, 6:00 PM
Weekend At Bernie's
The Outer Space Ballroom Hamden, CT
Sat Jan 16, 6:00 PM
New Year's Eve
The Queens Kickshaw Astoria, NY
Thu Dec 31, 5:45 PM
Jukebox Madness: 2nd An...
Hermosa Ballroom at Robson Ranch Eloy, AZ
Fri Jan 22, 6:00 PM
VDAY 2016 - The Vagina...
The Church Within Indianapolis, IN
Fri Feb 12, 7:00 PM
DTLA December Queer Mal...
Santee Village Lofts Los Angeles, CA
Sun Dec 27, 1:00 PM
Perlesque
All that Glitters Burlesque Academy Portland, OR
Fri Mar 18, 6:00 PM
Weekend At Bernie's
The Outer Space Ballroom Hamden, CT
Sat Jan 16, 6:00 PM
New Year's Eve
The Queens Kickshaw Astoria, NY
Thu Dec 31, 5:45 PM
Jukebox Madness: 2nd An...
Hermosa Ballroom at Robson Ranch Eloy, AZ
Fri Jan 22, 6:00 PM
VDAY 2016 - The Vagina...
The Church Within Indianapolis, IN
Fri Feb 12, 7:00 PM
Boswick The Clown's Hol...
Shelton Theatre San Francisco, CA
Sat Dec 26, 11:00 AM
SHAKE RATTLE, AND ROLL...
United Methodist Church Atascadero,, CA
Fri Feb 05, 1:00 PM
Kabare - Pricaj mi o lj...
Beverley Halls SPK Toronto, ON
Fri Feb 12, 8:30 PM
Sphere Ensemble: The Mo...
Broomfield Auditorium Broomfield , CO
Sun Mar 20, 2:00 PM
R&B For The Soul
Radisson Hotel (Whittier, CA) Whittier, CA
Sat Feb 13, 9:00 PM
5K Salmon Run & Nature...
Ovenell's Double O Ranch Concrete, WA
Sat Jan 02, 9:00 AM
Boswick The Clown's Hol...
Shelton Theatre San Francisco, CA
Sat Dec 26, 11:00 AM
SHAKE RATTLE, AND ROLL...
United Methodist Church Atascadero,, CA
Fri Feb 05, 1:00 PM
Kabare - Pricaj mi o lj...
Beverley Halls SPK Toronto, ON
Fri Feb 12, 8:30 PM
Sphere Ensemble: The Mo...
Broomfield Auditorium Broomfield , CO
Sun Mar 20, 2:00 PM
R&B For The Soul
Radisson Hotel (Whittier, CA) Whittier, CA
Sat Feb 13, 9:00 PM
5K Salmon Run & Nature...
Ovenell's Double O Ranch Concrete, WA
Sat Jan 02, 9:00 AM
Boswick The Clown's Hol...
Shelton Theatre San Francisco, CA
Sat Dec 26, 11:00 AM
SHAKE RATTLE, AND ROLL...
United Methodist Church Atascadero,, CA
Fri Feb 05, 1:00 PM
Kabare - Pricaj mi o lj...
Beverley Halls SPK Toronto, ON
Fri Feb 12, 8:30 PM
Buon Natale: The Befana...
St. Bede's Episcopal Church Los Angeles, CA
Sat Jan 09, 8:00 PM
ARTS |
HMCT Presents South Pac...
Church of the Nazarene North Haledon, NJ
Fri Feb 05, 8:00 PM
Nips-N-Tips: Never Too...
Jewelbox Theater at the Rendezvous Seattle, WA
Thu Jan 14, 7:00 PM
21st Annual Bank of Ame...
Museum of Discovery and Science Fort Lauderdale, FL
Fri Apr 08, 5:30 PM
Austin Anarchy Roller D...
Austin Sports Arena Round Rock, TX
Sat Mar 19, 7:30 PM
Buon Natale: The Befana...
St. Bede's Episcopal Church Los Angeles, CA
Sat Jan 09, 8:00 PM
Storytelling Workshops
Port Angeles Library Port Angeles, WA
Tue Jan 05, 6:00 PM
HMCT Presents South Pac...
Church of the Nazarene North Haledon, NJ
Fri Feb 05, 8:00 PM
Nips-N-Tips: Never Too...
Jewelbox Theater at the Rendezvous Seattle, WA
Thu Jan 14, 7:00 PM
21st Annual Bank of Ame...
Museum of Discovery and Science Fort Lauderdale, FL
Fri Apr 08, 5:30 PM
Austin Anarchy Roller D...
Austin Sports Arena Round Rock, TX
Sat Mar 19, 7:30 PM
Buon Natale: The Befana...
St. Bede's Episcopal Church Los Angeles, CA
Sat Jan 09, 8:00 PM
Storytelling Workshops
Port Angeles Library Port Angeles, WA
Tue Jan 05, 6:00 PM
HMCT Presents South Pac...
Church of the Nazarene North Haledon, NJ
Fri Feb 05, 8:00 PM
Midwinter Bash January...
Buffalo Niagara Court Center West Seneca, NY
Fri Jan 15, 7:00 PM
Shakespeare in Music
King's Chapel Boston, MA
Sun Jan 24, 5:00 PM
1/15 The Winterlings
Fremont Abbey Arts Center Seattle, WA
Fri Jan 15, 8:00 PM
Foghorn Stringband
Unitarian Universalist Fellowship... Newark, DE
Fri Apr 22, 8:00 PM
EVENT GRAB BAG |
Excognito Dance Festiva...
The Actor's Fund Arts Center Brooklyn, NY
Fri Jan 08, 7:30 PM
Midwinter Bash January...
Buffalo Niagara Court Center West Seneca, NY
Fri Jan 15, 7:00 PM
Shakespeare in Music
King's Chapel Boston, MA
Sun Jan 24, 5:00 PM
FOOD & DRINK |
Foghorn Stringband
Unitarian Universalist Fellowship... Newark, DE
Fri Apr 22, 8:00 PM
23rd Annual Women's Nig...
Chez Josef Agawam, MA
Thu Mar 31, 5:30 PM
Excognito Dance Festiva...
The Actor's Fund Arts Center Brooklyn, NY
Fri Jan 08, 7:30 PM
MOVIES & FILM |
Shakespeare in Music
King's Chapel Boston, MA
Sun Jan 24, 5:00 PM
1/15 The Winterlings
Fremont Abbey Arts Center Seattle, WA
Fri Jan 15, 8:00 PM
| The fair-trade ticketing company
Find an event
| Browse all events
Post an event With no fees to sell tickets and live 24/7 phone and web sales, Brown Paper Tickets is the smartest way to sell tickets for your next event! Ticket buyers pay just $0.99 + 3.5%, including delivery and credit card processing! Post your event for free and experience the power of Brown Paper Tickets!
| Convince me!
| Always free to create events and sell tickets!
| Live in-house 24/7 phone sales and support!
| Free ticket printing and shipping for your ticket buyers!
| Way more features than we can possibly list in four bullet points!
Learn more!
Hear from our producers:
"I have enjoyed working with Brown Paper Tickets over the last several months. You guys make ticket sales about as easy as it could possibly be."
Scott W. Chicago, IL United States
What's new at Brown Paper Tickets
New Scanner App | Video: Music + Radio Stars | On the blog
We redesigned our mobile scanner app. A speedier performance and dare-we-say stunning interface. Streamline event entry. Scan tickets and check in guests from mobile devices. View guests admitted and tickets remaining at a tap. Unscan and rescan tickets so guests come and go. Free app now available. | Why do DJs rock? Punk. Folk. Hip hop. Jazz. Music and radio shape, transform, connect and transcend our souls and minds. Who hasn't been inspired by a killer DJ? Meet 3 independent radio DJs who find passion spinning tunes for listeners, talking to local guests and using the power of airwaves and podcasts to nurture community. | ## How to Build Intensity with Your Event Playlist 09 December 2015 2:30 PM As a producer and organizer of live music and cabaret events, nothing irks me more than going to a show and hearing house music that has zero to do with the event. Know what I'm talking about? Sure you do. Ever been to hear your friend's indie rock band and the sound person blares loud<br /> <a cl...
Apple Store Google Play | Watch Now | Read More

Contact us
Email
support@brownpapertickets.com
24/7 Customer Service
1-800-838-3006 US, Canada, Puerto Rico
Resources
Careers
Press
Developers
Help
Ticket Buyers
Track Your Order
Browse Events
Locations
Event Producers
Create an Event
Pricing
Services
Buy Pre-Printed Tickets
The Venue List

Join the mailing list
Get spam-free daily notifications of new events in your neighborhood!
Customize your mailing list

Connect with us

| Friend us on Facebook
| Follow us on Twitter
| Watch us on YouTube
| Read our blog
| Get to know us
| Meet the Doers

Use of Brown Paper Tickets is subject to our Terms & Conditions. All rights reserved. © 2000-2015 | Mobile EN ES FR